pub trait RewardSource<AccountId, Balance> {
// Required methods
fn account() -> Option<AccountId>;
fn paid(amount: Balance);
}Expand description
Provides the account that reward payments and invulnerable fee refunds are drawn from.
None mints directly. Some(account) transfers from account, followed by a call to
Self::paid for any bookkeeping the source needs to perform after a successful payout.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.